![Python application](https://github.com/AWehrhahn/ExoOrbits/workflows/Python%20application/badge.svg)

ExoOrbits
---------

Simple python library to calculate the properties of exoplanet orbits.
Specifically the position and transit phase of the planet.
